@@ -66,12 +66,25 @@ class Nero(Coin):
                     "payment_id": res['payment_id']
                 }
 
-    async def list_txs(self, payment_id: str, *args, **kwargs) -> TransactionSet:
+    async def list_txs(self, address: str = None, payment_id: str = None, *args, **kwargs) -> TransactionSet:
         txset = TransactionSet()
         await self._generate_url()
 
-        if not isinstance(payment_id, str) or not payment_id:
-            raise Exception("bad payment_id")
+        height = 0
+        async with aiohttp.ClientSession() as session:
+            data = {
+                "jsonrpc": "2.0",
+                "id": "0",
+                "method": "get_height",
+            }
+
+            async with session.get(self.url, json=data) as resp:
+                blob = await resp.json()
+                height = blob.get('result', {}).get('height', 0)
+
+        if not height:
+            logging.error(f"could not get height at {self.url}")
+            return txset
 
         async with aiohttp.ClientSession() as session:
             data = {
@@ -86,13 +99,14 @@ class Nero(Coin):
             async with session.get(self.url, json=data) as resp:
                 blob = await resp.json()
                 if 'result' not in blob:
-                    raise Exception("Invalid response")
+                    raise Exception(f"Invalid response; {blob}")
 
                 res = blob['result']
-                if not isinstance(res['payments'], list):
-                    raise Exception("Invalid result response")
+                payments = res.get('payments', [])
+                if not payments:
+                    return txset
 
-                transactions = res['payments']
+                transactions = payments
                 for transaction in transactions:
                     amount = float(transaction['amount']) / self._div
 
@@ -100,7 +114,8 @@ class Nero(Coin):
                                      txid=transaction['tx_hash'],
                                      date=datetime.now(),
                                      blockheight=transaction['block_height'],
-                                     direction='in')
+                                     direction='in',
+                                     confirmations=(height - transaction['block_height']))
                     txset.add(tx)
 
         return txset
